@@ -1,6 +1,6 @@
 package Math::Abacus;
 
-use 5.10.0;
+use v5.10.0;
 use Carp;
 use feature 'say';
 
@@ -81,7 +81,7 @@ Version 0.02
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
     use Math::Abacus;
